@@ -6,13 +6,10 @@ if [ $# -ne 1 ]; then
 fi
 SEARCHUID=$1
 
-# mise à jour 2.4.1
-#. /usr/bin/ParseDico
-ecdl_smb_workgroup=$(CreoleGet smb_workgroup "vide")
-
+. /usr/bin/ParseDico
 
 BASE="ou=$ecdl_smb_workgroup,ou=domaines,ou=Samba,ou=applications,ou=ressources,dc=equipement,dc=gouv,dc=fr"
 CONNECT_DN="uid=SambaAdm.$ecdl_smb_workgroup,$BASE"
 
-ldapsearch -x -H ldaps://$(CreoleGet adresse_ip_ldap_distant) -D "$CONNECT_DN" -w "$(cat /etc/sysconfig/.pass)" -b "$BASE" -s sub -a always "(uid=$SEARCHUID)" dn
+ldapsearch -x -H ldaps://ldapsmb.m2.e2.rie.gouv.fr -D "$CONNECT_DN" -w "$(cat /etc/sysconfig/.pass)" -b "$BASE" -s sub -a always "(uid=$SEARCHUID)" dn
 
