@@ -1,9 +1,7 @@
 #-*- coding: utf-8 -*-
 
-from pyeole.process import system_out
-from utils import repr_value
 from subprocess import Popen, PIPE
-import shlex
+from .utils import repr_value
 
 def get_values(variables, empty=False):
     """
@@ -18,9 +16,8 @@ def get_values(variables, empty=False):
         command = [variable[1]]
         variable = variable[0]
         with open('/dev/null', 'w') as dev_null:
-            
             process = Popen(command, stderr=dev_null, stdout=PIPE, shell=True)
-            output = process.communicate()[0]
+            output = process.communicate()[0].decode('utf-8')
         if empty or output != '':
             values[variable] = repr_value(output)
     return values
